@@ -98,25 +98,15 @@ class MetricsCollector:
     ):
         global interimConfig
         interimConfig.maybeInitialize(spark, sessionForInteractive)
-        try:
-            spark.sparkContext._jvm.org.apache.spark.sql.MetricsCollector.start(
-                spark._jsparkSession, pipelineId, sessionForInteractive
-            )
-        except:
-            #### making sure for compatibility with older prophecy-libs releases
-            spark.sparkContext._jvm.org.apache.spark.sql.MetricsCollector.start(
-                spark._jsparkSession, sessionForInteractive
-            )
+        spark.sparkContext._jvm.org.apache.spark.sql.MetricsCollector.start(
+            spark._jsparkSession, pipelineId, sessionForInteractive
+        )
 
     @classmethod
     def end(cls, spark: SparkSession):
-        try:
-            spark.sparkContext._jvm.org.apache.spark.sql.MetricsCollector.end(
-                spark._jsparkSession
-            )
-        except:
-            #### making sure for compatibility with older prophecy-libs releases
-            spark.sparkContext._jvm.org.apache.spark.sql.MetricsCollector.end()
+        spark.sparkContext._jvm.org.apache.spark.sql.MetricsCollector.end(
+            spark._jsparkSession
+        )
         global interimConfig
         interimConfig.clear()
 
@@ -141,8 +131,7 @@ def createEventSendingListener(
     spark: SparkSession, execution_url: str, session: str, scheduled: bool
 ):
     spark.sparkContext._jvm.org.apache.spark.sql.MetricsCollector.addSparkListener(
-        spark._jsparkSession, execution_url, session, scheduled
-    )
+        spark._jsparkSession, execution_url, session, scheduled)
 
 
 def postDataToSplunk(props: dict, payload):
@@ -153,29 +142,28 @@ def postDataToSplunk(props: dict, payload):
     from urllib3 import Retry
 
     with requests.Session() as session:
-        with HTTPAdapter(
+
+        adapter = HTTPAdapter(
             max_retries=Retry(
                 total=int(props.get("maxRetries", 4)),
                 backoff_factor=float(props.get("backoffFactor", 1)),
                 status_forcelist=[429, 500, 502, 503, 504],
             )
-        ) as adapter:
-            session.mount("http://", adapter)
-            session.headers.update(
-                {
-                    "Authorization": "Splunk " + props["token"],
-                    "Content-Encoding": "gzip",
-                    "BatchId": props.get("batchId", None),
-                }
-            )
-            try:
-                res = session.post(
-                    props["url"], gzip.compress(bytes(payload, encoding="utf8"))
-                )
-                if res.status_code != 200 and props.get("stopOnFailure", False):
-                    raise HTTPError(res.reason)
-            finally:
-                session.close()
+        )
+        session.mount("http://", adapter)
+        session.headers.update(
+            {
+                "Authorization": "Splunk " + props["token"],
+                "Content-Encoding": "gzip",
+                "BatchId": props.get("batchId", None),
+            }
+        )
+        res = session.post(
+            props["url"], gzip.compress(bytes(payload, encoding="utf8")), verify=(not props.get("skipSsl", False)), cert=props.get("certFilePath")
+        )
+        print(f"IN SESSION URL={props['url']} res.status_code = {res.status_code} res={res.text}")
+        if res.status_code != 200 and props.get("stopOnFailure", False):
+            raise HTTPError(res.reason)
 
 
 def splunkHECForEachWriter(props: dict):
@@ -194,7 +182,7 @@ def splunkHECForEachWriter(props: dict):
                     postDataToSplunk(props, payload)
                     payload, prevsize = "", 0
                 else:
-                    payload += '{"event":' + row + "}"
+                    payload += '{"event":' + row + '}'
                     prevsize += len(row) + 10  # 10 bytes is for padding
 
             if payload:
